@@ -4,8 +4,11 @@
 
 import inspect
 from types import FunctionType, MethodType, ModuleType
-from typing import Any, Callable, Coroutine
+from typing import Any, Callable, Coroutine, ForwardRef
 from .TheoryManager import TheoryManager
+from ..traits.Trait import Trait
+
+Trait = ForwardRef('Trait')
 
 class Theory:
 
@@ -14,6 +17,7 @@ class Theory:
     __moduleName:str
     __target:FunctionType|MethodType
     __testName:str
+    __traits:list[Trait]
 
     def __init__(self, moduleName:str, target:FunctionType|MethodType, className:str = None, testName:str = None):
         self.__className = className
@@ -21,6 +25,7 @@ class Theory:
         self.__moduleName = moduleName
         self.__target = target
         self.__testName = testName
+        self.__traits = []
 
     @property
     def className(self) -> str:
@@ -40,8 +45,12 @@ class Theory:
 
     @property
     def testName(self) -> str:
-        return self.__testName
-    
+        return self.__testName if self.__testName is not None else self.__target.__qualname__.split('.')[-1]
+
+    @property
+    def traits(self) -> list[Trait]:
+        return self.__traits
+
     @property
     def filterName(self) -> str:
         return f'{self.moduleName}/{"" if self.className is None or len(self.className) == 0 else f"{self.className}/"}{self.testName}'
@@ -73,6 +82,7 @@ class Theory:
         if inspect.iscoroutine(coro):
             await coro
 
+
 def theory(target:Callable) -> Callable:
     if (not inspect.isfunction(target)) and (not isinstance(target, classmethod)) and (not isinstance(target, staticmethod)):
         raise Exception('@theory can only be applied to functions and methods.')
@@ -80,6 +90,7 @@ def theory(target:Callable) -> Callable:
     TheoryManager.instance().put(theory)
     return target
 
+
 def inlinedata(*args) -> Callable:
     def wrapper(target:Callable) -> Callable:
         if args is not None and len(args) > 0:
